summaryrefslogtreecommitdiff
path: root/lib/coderay/helpers
diff options
context:
space:
mode:
Diffstat (limited to 'lib/coderay/helpers')
-rw-r--r--lib/coderay/helpers/plugin.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/coderay/helpers/plugin.rb b/lib/coderay/helpers/plugin.rb
index aba6ff7..445d500 100644
--- a/lib/coderay/helpers/plugin.rb
+++ b/lib/coderay/helpers/plugin.rb
@@ -32,9 +32,9 @@ module PluginHost
PLUGIN_HOSTS = []
PLUGIN_HOSTS_BY_ID = {} # dummy hash
# Loads all plugins using all_plugin_names and load.
def load_all
- for plugin in all_plugin_names
+ for plugin in list
load plugin
end
end
@@ -160,7 +160,7 @@ module PluginHost
# Returns an array of all .rb files in the plugin path.
#
# The extension .rb is not included.
- def all_plugin_names
+ def list
Dir[path_to('*')].select do |file|
File.basename(file)[/^(?!_)\w+\.rb$/]
end.map do |file|
@@ -32,9 +32,9 @@ module PluginHost
PLUGIN_HOSTS = []
PLUGIN_HOSTS_BY_ID = {} # dummy hash
- # Loads all plugins using all_plugin_names and load.
+ # Loads all plugins using list and load.
def load_all